@@ -13,7 +13,10 @@ def softmax(tensor) -> np.ndarray:
 def tpu_tensor_to_num_classes(tensor: np.ndarray, top: int = 1) -> np.ndarray:
     """Get top N classes of output tensor."""
     tensor = np.reshape(tensor, (tensor.shape[0], tensor.shape[-1]))
-    num_classes = np.squeeze(tensor.argsort()[::, -top:])
+    num_classes = np.squeeze(tensor.argsort()[::, -top:])[()]
+    # the operation '[()]' returns number if the array in 0-d and returns an array otherwise
+    if not isinstance(num_classes, np.ndarray):
+        num_classes = np.array([num_classes])
     return num_classes
 
 
